%% COMPUTESTATS creates statistics for index data

%% 1. Create datastore
fileList = 'indexData\indices*.txt'; 
ds = datastore(fileList, 'Delimiter', ',');

%% 2. Adjust datastore settings
varNames = ds.VariableNames(2:end); % first column is dates
ds.SelectedVariableNames = varNames;
ds.ReadSize = 'file';

%% 3. Determine sums and sums of squares for each file
parfor k = 1:numel(ds.Files)
    t = read(partition(ds, 'Files', k));
    [sums(k,:), summedSquares(k,:), numObs(k)] = calculateStats(t);
end

%% 4. Determine means and standard deviations
% $s_{N-1} = \sqrt{ \left( \frac{1}{N} \sum_{i=1}^N x_i^2 \right) - 
% \left( \frac{1}{N} \sum_{i=1}^N x_i \right)^2 } * \sqrt{ \frac{N}{N-1} }$
totalNumObs = sum(numObs);
means = sum(sums) / totalNumObs;
stds = sqrt(sum(summedSquares) / totalNumObs - means.^2) * ...
       sqrt(totalNumObs/(totalNumObs-1));

%% 5. Visualize results 
visualizeMeanStd(means, stds, varNames)