function prc = gdpCpu_sepfun(numPaths)
% GDPCPU simulates the GDP in the US
% 10 years from now, based on historic data.
%
% Example:
%   >> prc = gdpCpu_sepfun(1e4)
% If this runs quickly, try more simulations.

% Load data and set parameters
load('usEconQuart.mat','usEcon');
GDP = usEcon.GDP;
numSteps = 40;

% Calculate logarithmic returns and fit to non-parametric distribution
logReturns = diff(log(GDP)); % same as log(GDP(2:end)./GDP(1:end-1));
myfit = fitdist(logReturns,'kernel');

% Obtain table of percentiles
x = 0.001:0.001:0.999;
y = icdf(myfit,x);

% Call computation function and show histogram
simGDP = simulations(x, y, GDP(end),numSteps,numPaths);
histogram(simGDP,50)
title(['Final prices of ' num2str(numPaths) ' simulations'])
prc = prctile(simGDP,[1 5 10 50]);